@@ -4,6 +4,8 @@
 #
 # Tested on several systems only
 # ttt1 Quite likely this needs changes to work with other distros and / or versions
+#
+# by passing the param "QMAKE_CXX=clang" the project will be compiled with clang
 
 
 bash ./AdjustMt.sh STATIC_SER
@@ -26,12 +28,24 @@ if [ -f /etc/fedora-release ] ; then
     QMake=qmake-qt4
 fi
 
-$QMake
+if [ -d bin ] ; then
+    rm bin/*
+fi
+
+if [[ "$1" != "" ]] ; then
+    $QMake "$1"
+else
+    $QMake
+fi
+
 if [ $? -ne 0 ] ; then exit 1 ; fi
 
 make
 if [ $? -ne 0 ] ; then exit 1 ; fi
 
+./MakeTranslations.sh
+cp src/translations/*.qm bin
+
 BranchSlash=`cat branch.txt`
 BranchDash=`echo "$BranchSlash" | sed 's#/#-#'`
 exe=MP3Diags$BranchDash
@@ -40,9 +54,9 @@ strip bin/$exe
 
 Cpu=`uname -m`
 
-cd bin
-NewName=$exe-Linux-$Cpu-1.0.12.079
-mv $exe $NewName
-tar -c $NewName | bzip2 > $NewName.tar.bz2
-mv $NewName $exe
-cd ..
+NewName=$exe-Linux-$Cpu-1.2.01
+mv bin/$exe bin/$NewName
+tar -c bin | bzip2 > $NewName.tar.bz2
+mv $NewName.tar.bz2 bin
+mv bin/$NewName bin/$exe
+
